package lt05_pkg;

import java.awt.Color;
import java.awt.Component;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;

import lt05_pkg.PolkaDot;
import lt05_pkg.PolkaDotDataModel;

import javax.swing.JFrame;

/**
 * This class encapsulates a MouseListener that is installed upon a particular
 * JFrame. When a mouse motion event is detected, this controller changes the
 * PolkaDotDataModel. For specific details, see {@link #mouseMoved(MouseEvent)}
 * 
 * @author mb
 */
public class DotController_VersionForQuestion6 implements MouseListener,
		MouseMotionListener {

	private PolkaDotDataModel theModel;
	private JFrame theView;

	public DotController_VersionForQuestion6(JFrame view,
			PolkaDotDataModel model) {
		theModel = model;
		theView = view;

		/**
		 * The components of the view will generate events; these are produced
		 * when the user performs user actions. We want the controller to be
		 * aware of such events so that it can update the model accordingly.
		 * 
		 */
		theView.addMouseListener(this);
		theView.addMouseMotionListener(this);
	}

	/**
	 * This method does cause anything to happen to the data model. See
	 * {@link #mouseMoved(MouseEvent)} instead.
	 */
	@Override
	public void mouseClicked(MouseEvent e) {
	}

	@Override
	public void mousePressed(MouseEvent e) {
	}

	@Override
	public void mouseReleased(MouseEvent e) {
	}

	@Override
	public void mouseEntered(MouseEvent e) {
	}

	@Override
	public void mouseExited(MouseEvent e) {
	}

	@Override
	public void mouseDragged(MouseEvent e) {
	}

	/**
	 * This method causes the data model to be changed when a mouse move event
	 * is detected. What this method should do:
	 * 
	 * any time the user moves the mouse pointer, evaluate whether the pointer
	 * has passed inside a polka dot. If the mouse pointer passes inside a polka
	 * dot, then the polka dot should change: if it is unfilled, then it should
	 * become filled. If it is filled, then it should become unfilled. The
	 * effect is that as the user moves the mouse track point within a polka
	 * dot, the polka dot should toggle rapidly between between filled and
	 * unfilled.
	 * 
	 * Hint: look at the services provided by the class {@link PolkaDot}
	 */
	@Override
	public void mouseMoved(MouseEvent e) {
		Point pointOfMouseTracker = e.getPoint();
		PolkaDot d = theModel.getMatchingDot(pointOfMouseTracker);
		if (d != null && d.isFilled()) {
			d.setFilled(false);
		} else if (d != null && !d.isFilled()) {
			d.setFilled(true);
		}

	}

}
